"""Top-level package for workshop_schedules."""

__author__ = """ René Fritze"""
__email__ = ' rené.fritze@wwu.de'

from ._version import get_versions

__version__ = get_versions()['version']
del get_versions
